summaryrefslogtreecommitdiff
path: root/rows.go
diff options
context:
space:
mode:
Diffstat (limited to 'rows.go')
-rw-r--r--rows.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/rows.go b/rows.go
index 5808530..7e2d677 100644
--- a/rows.go
+++ b/rows.go
@@ -202,13 +202,13 @@ func appendSpace(l int, s []string) []string {
return s
}
// ErrSheetNotExist defines an error of sheet is not exist
type ErrSheetNotExist struct {
SheetName string
}
func (err ErrSheetNotExist) Error() string {
- return fmt.Sprintf("sheet %s is not exist", err.SheetName)
+ return fmt.Sprintf("sheet %s does not exist", err.SheetName)
}
// rowXMLIterator defined runtime use field for the worksheet row SAX parser.
@@ -202,13 +202,13 @@ func appendSpace(l int, s []string) []string {
return s
}
-// ErrSheetNotExist defines an error of sheet is not exist
+// ErrSheetNotExist defines an error of sheet that does not exist
type ErrSheetNotExist struct {
SheetName string